import React from 'react';
import clsx from 'clsx';
import linkifyIt from 'linkify-it';
import tlds from 'tlds';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var linkify = linkifyIt();
linkify.tlds(tlds);
// The component we render when we encounter a hyperlink in the text
function Link(props) {
  var _props$decoratedText = props.decoratedText,
      decoratedText = _props$decoratedText === void 0 ? '' : _props$decoratedText,
      _props$theme = props.theme,
      theme = _props$theme === void 0 ? {} : _props$theme,
      _props$target = props.target,
      target = _props$target === void 0 ? '_self' : _props$target,
      _props$rel = props.rel,
      rel = _props$rel === void 0 ? 'noreferrer noopener' : _props$rel,
      className = props.className,
      component = props.component,
      dir = props.dir,
      entityKey = props.entityKey,
      getEditorState = props.getEditorState,
      offsetKey = props.offsetKey,
      setEditorState = props.setEditorState,
      contentState = props.contentState,
      blockKey = props.blockKey,
      start = props.start,
      end = props.end,
      otherProps = _objectWithoutPropertiesLoose(props, ["decoratedText", "theme", "target", "rel", "className", "component", "dir", "entityKey", "getEditorState", "offsetKey", "setEditorState", "contentState", "blockKey", "start", "end"]);

  var combinedClassName = clsx(theme == null ? void 0 : theme.link, className);
  var links = linkify.match(decoratedText);
  var href = links && links[0] ? links[0].url : '';

  var linkProps = _extends({}, otherProps, {
    href: href,
    target: target,
    rel: rel,
    className: combinedClassName
  });

  return component ? /*#__PURE__*/React.createElement(component, linkProps) :
  /*#__PURE__*/
  // eslint-disable-next-line jsx-a11y/anchor-has-content
  React.createElement("a", linkProps);
}

var linkify$1 = linkifyIt();
linkify$1.tlds(tlds); // Gets all the links in the text, and returns them via the callback

var linkStrategy = function linkStrategy(contentBlock, callback) {
  var links = linkify$1.match(contentBlock.get('text'));

  if (typeof links !== 'undefined' && links !== null) {
    for (var i = 0; i < links.length; i += 1) {
      callback(links[i].index, links[i].lastIndex);
    }
  }
};

var defaultTheme = {
  link: "lxvs42t"
};

var index = (function (config) {
  if (config === void 0) {
    config = {};
  }

  // Styles are overwritten instead of merged as merging causes a lot of confusion.
  // Why? Because when merging a developer needs to know all of the underlying
  // styles which needs a deep dive into the code. Merging also makes it prone to
  // errors when upgrading as basically every styling change would become a major
  // breaking change. 1px of an increased padding can break a whole layout.
  var _config = config,
      component = _config.component,
      _config$theme = _config.theme,
      theme = _config$theme === void 0 ? defaultTheme : _config$theme,
      _config$target = _config.target,
      target = _config$target === void 0 ? '_self' : _config$target,
      _config$rel = _config.rel,
      rel = _config$rel === void 0 ? 'noreferrer noopener' : _config$rel;

  var DecoratedLink = function DecoratedLink(props) {
    return /*#__PURE__*/React.createElement(Link, _extends({}, props, {
      theme: theme,
      target: target,
      rel: rel,
      component: component
    }));
  };

  return {
    decorators: [{
      strategy: linkStrategy,
      component: DecoratedLink
    }]
  };
});

export default index;
